/* -------------------------------------------------------------------
 * 
 * Author: Blupixel IT Srl
 * Last Modifcation Date: 5th August 2012
 * Website: www.blupixelit.eu
 * support at: webmaster@blupixelit.eu
 * 
 * Copyright (c) 2012 Blupixel IT Srl - Trento (Italy)
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * 
 * Applied to one or more dom elements, the script display in an overlay
 * layer the image set in the attribute data-img of the element
 * 
 * How To Use:
 * - simply call the function name: 
 *     jQuery('#mydom').bITPreview();
 *  on an element that has the data-img attribute set with the bigger image address
 * - or use additional params: 
 *     jQuery('#mydom').bITPreview({
 *       loadingImage: '/myimages/loading.gif', 
 *       refAttribute: 'data-href'
 *     });
 * 
 * Possible Parameters:
 * - refAttribute: text
 *     is the attribute to get the image address from
 * - height: number
 *     if adaptToImage is false determine the height of the layer containing image
 * - width: number
 *     if adaptToImage is false determine the width of the layer containing image
 * - css: object
 *     object containing all the css params in jQuery standard to be applied to the
 *     layer containing the big image
 * - mouseDistance: number
 *     distance in pixel from the mouse cursor when the layer appears
 * - topOffset: number (positive or negative)
 *     number of pixel to be added to the top position of the layer when 
 *     it appears
 * - adaptToImage: boolean
 *     if true adapt the layer to the image contained even if width and 
 *     height have been set
 * - adaptToImagePadding: number
 *     set the padding of the layer containing the bigger image
 * - loadingImage: text
 *     it's the address of the loading image  to be displayed while the 
 *     other one is loading
 * 
 * ----------------------------------------------------------------- */ 

(function($) {
    $.fn.bITPreview = function(options) {
		$.fn.bITPreview.defaults = {
		  refAttribute: 'data-img',
		  height: 300,
		  width: 300,
		  css: {
			backgroundColor: '#FFFFFF',
			opacity: '1',
			border: '1px solid #000000',
			textAlign: 'center',
			borderRadius: 10
		  },
		  mouseDistance: 10,
		  topOffset: -150,
		  adaptToImage: true,
		  adaptToImagePadding: 10,
		  loadingImage: 'images/loading.gif'
		};

		options = $.extend({}, $.fn.bITPreview.defaults, options);
        var container = $('<div class="bITPreview_container"><img src="'+options.loadingImage+'"/></div>');
        container.hide();
        container.width(options.width);
        container.height(options.height);
        container.css('position', 'absolute');
        container.css(options.css);
        $('body').append(container);
        
		return this.each(function() {
			$(this).hover(function(evt) {
				$('.bITPreview_container img').attr('src', $(this).attr(options.refAttribute));
				var img_width = $(this).width();
				if (options.adaptToImage) {
					$(function() {
						$('.bITPreview_container').width('auto');
						$('.bITPreview_container').height('auto');
						$('.bITPreview_container').css('borderRadius', '0');
						$('.bITPreview_container').css('padding', options.adaptToImagePadding);
					});
				}
				$('.bITPreview_container').css({
					top: evt.pageY + options.topOffset,
					left: evt.pageX + options.mouseDistance
				  }).show();
			}, function() {
				$('.bITPreview_container img').attr('src', options.loadingImage);
				$('.bITPreview_container').hide();
			});
		});
	}
})(jQuery);
